@@ -36,11 +36,12 @@ MODULE_PRESETS = {
     'cuda11': ['cuda/11.0.194'],
     'cuda11.1': ['cuda/11.1.74'],
     'cuda11.3': ['cuda/11.3.1'],
+    'conda': ['anaconda3/2020.07'],
+    'anaconda': ['anaconda3/2020.07'],
+    'anaconda3': ['anaconda3/2020.07'],
 }
 # cuda           cuda/10.2.89   cuda/11.0.194  cuda/11.1.74   cuda/11.3.1
 
-DEFAULT_CONDA_VERSION = '2020.07'
-
 class SlurmBatch(BaseBatch):
     '''
 
@@ -54,7 +55,6 @@ class SlurmBatch(BaseBatch):
         nodes=1,
         conda_env=None,
         run_dir='.',
-        conda_version='auto',
         email=None,
         modules=[],
         sbatch_options=dict(
@@ -73,8 +73,6 @@ class SlurmBatch(BaseBatch):
         modules = util.flatten(
             self.module_presets.get(m, m) for m in (modules or ()))
         super().__init__(*a, modules=modules, **kw)
-        if self.job_args.get('conda_version') == 'auto':
-            self.job_args['conda_version'] = DEFAULT_CONDA_VERSION
 
     def get_paths(self, name, root_dir='sbatch', **kw):
         paths = pathtree.tree(root_dir, {'{name}': {
